import React, { useState } from 'react'
import IUserDto from '../../interfaces/IUserCreateDto'
import styles from './Register.module.css'
import {useNavigate} from 'react-router-dom'
import { shallowEqual, useDispatch, useSelector } from 'react-redux'
import { AppDispatch, AppState } from '../../store/store'
import {register} from '../../store/users/users.slice'


const Register: React.FunctionComponent = (): React.ReactElement => {
    const {messageUser, isAuth} = useSelector((state: AppState) => state.users, shallowEqual)
    const navigate = useNavigate()
    const dispatch: AppDispatch = useDispatch()
    const [values, setValues] = useState<IUserDto>({
        username: '',
        password: ''
    })
    const inputHandler = (e: React.ChangeEvent<HTMLInputElement>): void => {
        setValues(prevState => {
            return {...prevState, [e.target.name]: e.target.value}
        })
    }
    const registerHandler = async (e: React.FormEvent) => {
        e.preventDefault()
        dispatch(register(values))
        isAuth && navigate('/')
    }
    return (
        <>
                <div>
                    <form onSubmit={registerHandler} className={styles.Login}>
                        <span>{messageUser}</span>
                        <input onChange={inputHandler} value={values.username} placeholder='Username' className={styles.Login__input} type="text" name={'username'} required />
                        <input onChange={inputHandler} value={values.password} placeholder='Password' className={styles.Login__input} type="password" name={'password'} required />
                        <button className={styles.Login__button}>Sign Up</button>
                    </form>
                </div>
        </>
        
    )
}

export default Register